polyfemos.data.utils — polyfemos 0.3.29 documentation

# polyfemos.data.utils

Miscellanous data manipulation functions

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.data.utils.` `log10_decimation`(data, maxn=100)

  Remove datapoints logarithmicly remove every n datapoints starting from 0, ending maxn-1 n increases exponentially Mainly used for logarithmic plotting where there are too many datapoints to be properly plot

  Returns decimated data as list

  Parameters

    - data (list or array-like) – data array to be decimated

    - maxn (int) – defines the amount of decimation made

  Return type

    list

  Returns

    Logarithmically decimated list